<!-- Copyright 2024 Remy Blank <remy@c-space.org> -->
<!-- SPDX-License-Identifier: MIT -->

# t-doc - Common

[![Publish](https://github.com/t-doc-org/common/actions/workflows/publish.yml/badge.svg)](https://github.com/t-doc-org/common/actions/workflows/publish.yml)

This package contains the common functionality for documents based on t-doc.

This software is distributed under the [MIT](LICENSE.txt) license.
